#include <File.au3>



Global $sSourcePath = @ScriptDir & "\pdfcreatorDir\PDFCreator.pdf" ; Datei die PDFCreator die Dateien erstellt.

Global $sResultFolder = @ScriptDir & "\ArtikelnummerDir\" ; Ordner, in den deine Ergebnisse abgelegt werden.

Global $sXPDF = @ScriptDir & "\pdftotext\pdftotext.exe" ; Pfad der pdftotext.exe



$sContent = _GetContent_PDF($sSourcePath) ; Funktion gibt den Text als String zurück.
$aMatches = StringRegExp($sContent, "ARTIKEL\h+:\h+([0-9.]+)_", 3) ; Das Pattern von chesstiger, um die Artikelnummer auszulesen.
If @error Then MsgBox(0, "", "Fehler beim Auslesen der Artikelnummer!")


Global $sNewFullPath = $sResultFolder & $aMatches[0] & ".pdf" ; Zielpfad der neuen Datei.

If FileExists($sNewFullPath) Then ; Wenn die Datei bereits existiert.
	Local $i = 1
	Do
		$sNewFullPath = $sResultFolder & $aMatches[0] & "_" & $i & ".pdf" ; In Schleife wird hochgezählt.
		$i += 1
	Until Not FileExists($sNewFullPath) ; Bis neu konstruierter Dateiname nicht existiert.
EndIf

FileMove($sSourcePath, $sNewFullPath, 8) ; Datei wird verschoben/umbenannt.






Func _GetContent_PDF($sFullPath)
	Local $sTempFile = _TempFile()

	Local $sFile = StringReplace($sTempFile, @TempDir & "\", "")

	Local $sTestread = _XPDF_ToText($sFullPath, $sFile, @TempDir)
	If @error Then Return MsgBox(0, "", "Fehler beim Lesen der PDF-Datei! (" & @error & ")", 4)
	Local $sString = FileRead($sTempFile)
	FileDelete($sTempFile)

	Return $sString

EndFunc   ;==>_GetContent_PDF


Func _XPDF_ToText($sPDFFile, $sTXTFile, $sTXTPath = @ScriptDir, $iFirstPage = 1, $iLastPage = 0, $bLayout = True) ; https://www.autoitscript.com/forum/topic/160718-code-to-extract-plain-text-from-a-pdf-file/?do=findComment&comment=1166469
	; #FUNCTION# ====================================================================================================================
	; Name...........: _XPDF_ToText
	; Description....: Converts a PDF file to plain  text.
	; Syntax.........: _XPDF_ToText ( "PDFFile" , "TxtFile" [ TxtPath[, FirstPage [, LastPage [, Layout ]]]] )
	; Parameters.....: PDFFile    - PDF Input File.
	;                  TxtFile    - Plain text fileneme to convert to
	;                  TxtPath    - Path to the txt file (default is @ScriptDir)
	;                  FirstPage  - First page to convert (default is 1)
	;                  LastPage   - Last page to convert (default is last page of the document)
	;                  Layout     - If true, maintains (as  best as possible) the original physical layout of the text
	;                               If false, the behavior is to 'undo'  physical  layout  (columns, hyphenation, etc.)
	;                                 and output the text in reading order.
	;                               Default is True
	; Return values..: Success - 1
	;                  Failure - 0, and sets @error to :
	;                   1 - PDF File not found
	;                   2 - Unable to find the external program
	; ===============================================================================================================================
	Local $sOptions

	If Not FileExists($sPDFFile) Then Return SetError(1, 0, 0)
	If Not FileExists($sXPDF) Then Return SetError(2, 0, 0)

	If $iFirstPage <> 1 Then $sOptions &= " -f " & $iFirstPage
	If $iLastPage <> 0 Then $sOptions &= " -l " & $iLastPage
	If $bLayout = True Then $sOptions &= " -layout"

	Local $iReturn = ShellExecuteWait($sXPDF, $sOptions & ' "' & $sPDFFile & '" "' & $sTXTFile & '"', $sTXTPath, "", @SW_HIDE)
	If $iReturn = 0 Then Return 1

	Return 0

EndFunc   ;==>_XPDF_ToText

